"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.api_client import ApiClient, Endpoint as _Endpoint
from unicourt.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from unicourt.model.case_export_callback import CaseExportCallback
from unicourt.model.case_export_callback_list_response import CaseExportCallbackListResponse
from unicourt.model.exception import Exception


class CaseExportApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.export_case_endpoint = _Endpoint(
            settings={
                'response_type': (CaseExportCallback,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseExport/{caseId}',
                'operation_id': 'export_case',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_id',
                ],
                'required': [
                    'case_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_id',
                ]
            },
            root_map={
                'validations': {
                    ('case_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_id':
                        (str,),
                },
                'attribute_map': {
                    'case_id': 'caseId',
                },
                'location_map': {
                    'case_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_export_callback_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (CaseExportCallback,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseExport/callbacks/{caseExportCallbackId}',
                'operation_id': 'get_case_export_callback_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_export_callback_id',
                ],
                'required': [
                    'case_export_callback_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_export_callback_id',
                ]
            },
            root_map={
                'validations': {
                    ('case_export_callback_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_export_callback_id':
                        (str,),
                },
                'attribute_map': {
                    'case_export_callback_id': 'caseExportCallbackId',
                },
                'location_map': {
                    'case_export_callback_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_export_callbacks_endpoint = _Endpoint(
            settings={
                'response_type': (CaseExportCallbackListResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseExport/callbacks',
                'operation_id': 'get_case_export_callbacks',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'date',
                    'status',
                    'page_number',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'status',
                ],
                'validation': [
                    'date',
                    'status',
                    'page_number',
                ]
            },
            root_map={
                'validations': {
                    ('date',): {
                        'max_length': 25,
                        'min_length': 25,
                    },
                    ('status',): {
                        'max_length': 11,
                        'min_length': 7,
                    },
                    ('page_number',): {

                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('status',): {

                        "IN_PROGRESS": "IN_PROGRESS",
                        "COMPLETE": "COMPLETE",
                        "FAILURE": "FAILURE"
                    },
                },
                'openapi_types': {
                    'date':
                        (datetime,),
                    'status':
                        (str,),
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'date': 'date',
                    'status': 'status',
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'date': 'query',
                    'status': 'query',
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def export_case(
        self,
        case_id,
        **kwargs
    ):
        """Gets case exported for a requested Case ID.  # noqa: E501

        Retrieve information about the specified case export.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.export_case(case_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_id (str): The caseId value of the case for which case export information is to be retrieved.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseExportCallback
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_id'] = \
            case_id
        return self.export_case_endpoint.call_with_http_info(**kwargs)

    def get_case_export_callback_by_id(
        self,
        case_export_callback_id,
        **kwargs
    ):
        """Get Case Export Callback for a requested Case Export Callback Id.  # noqa: E501

        Retrieve the specified case export callback object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_export_callback_by_id(case_export_callback_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_export_callback_id (str): The caseExportCallbackId value of the case export callback object to be retrieved.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseExportCallback
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_export_callback_id'] = \
            case_export_callback_id
        return self.get_case_export_callback_by_id_endpoint.call_with_http_info(**kwargs)

    def get_case_export_callbacks(
        self,
        **kwargs
    ):
        """Get Case Export Callback list for a requested Date.  # noqa: E501

        Retrieve callbacks according to the specified criteria.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_export_callbacks(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            date (datetime): The date for which callbacks are to be retrieved.. [optional]
            status (str): The status code of the callbacks to be retrieved.. [optional]
            page_number (int): The page number of the callbacks to be retrieved.<br>   - Minimum: 1 . [optional] if omitted the server will use the default value of 1
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseExportCallbackListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_case_export_callbacks_endpoint.call_with_http_info(**kwargs)




"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.model_utils import (  # noqa: F401
    ApiTypeError,
    ModelComposed,
    ModelNormal,
    ModelSimple,
    cached_property,
    change_keys_js_to_python,
    convert_js_args_to_python_args,
    date,
    datetime,
    file_type,
    none_type,
    validate_get_composed_info,
    OpenApiModel
)
from unicourt.exceptions import ApiAttributeError



class PACERCaseSearchContent(ModelNormal):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Attributes:
      allowed_values (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          with a capitalized key describing the allowed value and an allowed
          value. These dicts store the allowed enum values.
      attribute_map (dict): The key is attribute name
          and the value is json key in definition.
      discriminator_value_class_map (dict): A dict to go from the discriminator
          variable value to the discriminator class name.
      validations (dict): The key is the tuple path to the attribute
          and the for var_name this is (var_name,). The value is a dict
          that stores validations for max_length, min_length, max_items,
          min_items, exclusive_maximum, inclusive_maximum, exclusive_minimum,
          inclusive_minimum, and regex.
      additional_properties_type (tuple): A tuple of classes accepted
          as additional properties values.
    """

    allowed_values = {
        ('pcl_jurisdiction_type',): {
            'None': None,
            'APPELLATE': "Appellate",
            'BANKRUPTCY': "Bankruptcy",
            'CRIMINAL': "Criminal",
            'CIVIL': "Civil",
            'MULTI-DISTRICT_LITIGATION': "Multi-district Litigation",
            'NULL': "null",
        },
    }

    validations = {
        ('object',): {
            'max_length': 22,
            'min_length': 22,
        },
        ('pcl_case_link',): {
            'max_length': 255,
        },
        ('pcl_case_number_full',): {
            'max_length': 50,
        },
        ('pcl_case_title',): {
            'max_length': 255,
        },
        ('pcl_case_office',): {
            'max_length': 2,
        },
        ('pcl_case_type',): {
            'max_length': 6,
        },
        ('pcl_court_id',): {
            'max_length': 6,
        },
        ('pcl_date_filed',): {
            'max_length': 10,
        },
        ('pcl_mdl_court_id',): {
            'max_length': 10,
        },
        ('pcl_mdl_date_ordered',): {
            'max_length': 10,
        },
        ('pcl_mdl_date_received',): {
            'max_length': 10,
        },
        ('pcl_mdl_extension',): {
            'max_length': 50,
        },
        ('pcl_mdl_judge_last_name',): {
            'max_length': 50,
        },
        ('pcl_mdl_littype',): {
            'max_length': 50,
        },
        ('pcl_mdl_status',): {
            'max_length': 50,
        },
        ('pcl_mdl_transferee',): {
            'max_length': 50,
        },
        ('pcl_mdl_transferee_district',): {
            'max_length': 50,
        },
        ('pcl_civil_cto_number',): {
            'max_length': 50,
        },
        ('pcl_civil_date_disposition',): {
            'max_length': 10,
        },
        ('pcl_civil_date_initiated',): {
            'max_length': 10,
        },
        ('pcl_civil_date_terminated',): {
            'max_length': 10,
        },
        ('pcl_civil_stat_disposition',): {
            'max_length': 50,
        },
        ('pcl_civil_stat_initiated',): {
            'max_length': 50,
        },
        ('pcl_civil_stat_terminated',): {
            'max_length': 50,
        },
        ('pcl_civil_transferee',): {
            'max_length': 50,
        },
        ('pcl_bankruptcy_chapter',): {
            'max_length': 50,
        },
        ('pcl_date_discharged',): {
            'max_length': 10,
        },
        ('pcl_date_dismissed',): {
            'max_length': 10,
        },
        ('pcl_date_reopened',): {
            'max_length': 10,
        },
        ('pcl_date_termed',): {
            'max_length': 10,
        },
        ('pcl_disposition',): {
            'max_length': 100,
        },
        ('pcl_disposition_method',): {
            'max_length': 100,
        },
        ('pcl_joint_bankruptcy_flag',): {
            'max_length': 50,
        },
        ('pcl_joint_discharged_date',): {
            'max_length': 10,
        },
        ('pcl_joint_dismissed_date',): {
            'max_length': 10,
        },
        ('pcl_joint_disposition_method',): {
            'max_length': 100,
        },
        ('pcl_nature_of_suit',): {
            'max_length': 50,
        },
    }

    @cached_property
    def additional_properties_type():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded
        """
        return (bool, date, datetime, dict, float, int, list, str, none_type,)  # noqa: E501

    _nullable = False

    @cached_property
    def openapi_types():
        """
        This must be a method because a model may have properties that are
        of type self, this must run after the class is loaded

        Returns
            openapi_types (dict): The key is attribute name
                and the value is attribute type.
        """
        return {
            'object': (str,),  # noqa: E501
            'pcl_case_link': (str, none_type,),  # noqa: E501
            'pcl_jurisdiction_type': (str, none_type,),  # noqa: E501
            'pcl_case_id': (int,),  # noqa: E501
            'pcl_case_number_full': (str, none_type,),  # noqa: E501
            'pcl_case_title': (str, none_type,),  # noqa: E501
            'pcl_case_office': (str, none_type,),  # noqa: E501
            'pcl_case_number': (int,),  # noqa: E501
            'pcl_case_type': (str, none_type,),  # noqa: E501
            'pcl_case_year': (int,),  # noqa: E501
            'pcl_court_id': (str, none_type,),  # noqa: E501
            'pcl_date_filed': (str, none_type,),  # noqa: E501
            'pcl_jpml_number': (int, none_type,),  # noqa: E501
            'pcl_mdl_court_id': (str, none_type,),  # noqa: E501
            'pcl_mdl_date_ordered': (str, none_type,),  # noqa: E501
            'pcl_mdl_date_received': (str, none_type,),  # noqa: E501
            'pcl_mdl_extension': (str, none_type,),  # noqa: E501
            'pcl_mdl_judge_last_name': (str, none_type,),  # noqa: E501
            'pcl_mdl_littype': (str, none_type,),  # noqa: E501
            'pcl_mdl_status': (str, none_type,),  # noqa: E501
            'pcl_mdl_transferee': (str, none_type,),  # noqa: E501
            'pcl_mdl_transferee_district': (str, none_type,),  # noqa: E501
            'pcl_civil_cto_number': (str, none_type,),  # noqa: E501
            'pcl_civil_date_disposition': (str, none_type,),  # noqa: E501
            'pcl_civil_date_initiated': (str, none_type,),  # noqa: E501
            'pcl_civil_date_terminated': (str, none_type,),  # noqa: E501
            'pcl_civil_stat_disposition': (str, none_type,),  # noqa: E501
            'pcl_civil_stat_initiated': (str, none_type,),  # noqa: E501
            'pcl_civil_stat_terminated': (str, none_type,),  # noqa: E501
            'pcl_civil_transferee': (str, none_type,),  # noqa: E501
            'pcl_bankruptcy_chapter': (str, none_type,),  # noqa: E501
            'pcl_date_discharged': (str, none_type,),  # noqa: E501
            'pcl_date_dismissed': (str, none_type,),  # noqa: E501
            'pcl_date_reopened': (str, none_type,),  # noqa: E501
            'pcl_date_termed': (str, none_type,),  # noqa: E501
            'pcl_disposition': (str, none_type,),  # noqa: E501
            'pcl_disposition_method': (str, none_type,),  # noqa: E501
            'pcl_joint_bankruptcy_flag': (str, none_type,),  # noqa: E501
            'pcl_joint_discharged_date': (str, none_type,),  # noqa: E501
            'pcl_joint_dismissed_date': (str, none_type,),  # noqa: E501
            'pcl_joint_disposition_method': (str, none_type,),  # noqa: E501
            'pcl_nature_of_suit': (str, none_type,),  # noqa: E501
        }

    @cached_property
    def discriminator():
        return None


    attribute_map = {
        'object': 'object',  # noqa: E501
        'pcl_case_link': 'pclCaseLink',  # noqa: E501
        'pcl_jurisdiction_type': 'pclJurisdictionType',  # noqa: E501
        'pcl_case_id': 'pclCaseId',  # noqa: E501
        'pcl_case_number_full': 'pclCaseNumberFull',  # noqa: E501
        'pcl_case_title': 'pclCaseTitle',  # noqa: E501
        'pcl_case_office': 'pclCaseOffice',  # noqa: E501
        'pcl_case_number': 'pclCaseNumber',  # noqa: E501
        'pcl_case_type': 'pclCaseType',  # noqa: E501
        'pcl_case_year': 'pclCaseYear',  # noqa: E501
        'pcl_court_id': 'pclCourtId',  # noqa: E501
        'pcl_date_filed': 'pclDateFiled',  # noqa: E501
        'pcl_jpml_number': 'pclJpmlNumber',  # noqa: E501
        'pcl_mdl_court_id': 'pclMdlCourtId',  # noqa: E501
        'pcl_mdl_date_ordered': 'pclMdlDateOrdered',  # noqa: E501
        'pcl_mdl_date_received': 'pclMdlDateReceived',  # noqa: E501
        'pcl_mdl_extension': 'pclMdlExtension',  # noqa: E501
        'pcl_mdl_judge_last_name': 'pclMdlJudgeLastName',  # noqa: E501
        'pcl_mdl_littype': 'pclMdlLittype',  # noqa: E501
        'pcl_mdl_status': 'pclMdlStatus',  # noqa: E501
        'pcl_mdl_transferee': 'pclMdlTransferee',  # noqa: E501
        'pcl_mdl_transferee_district': 'pclMdlTransfereeDistrict',  # noqa: E501
        'pcl_civil_cto_number': 'pclCivilCtoNumber',  # noqa: E501
        'pcl_civil_date_disposition': 'pclCivilDateDisposition',  # noqa: E501
        'pcl_civil_date_initiated': 'pclCivilDateInitiated',  # noqa: E501
        'pcl_civil_date_terminated': 'pclCivilDateTerminated',  # noqa: E501
        'pcl_civil_stat_disposition': 'pclCivilStatDisposition',  # noqa: E501
        'pcl_civil_stat_initiated': 'pclCivilStatInitiated',  # noqa: E501
        'pcl_civil_stat_terminated': 'pclCivilStatTerminated',  # noqa: E501
        'pcl_civil_transferee': 'pclCivilTransferee',  # noqa: E501
        'pcl_bankruptcy_chapter': 'pclBankruptcyChapter',  # noqa: E501
        'pcl_date_discharged': 'pclDateDischarged',  # noqa: E501
        'pcl_date_dismissed': 'pclDateDismissed',  # noqa: E501
        'pcl_date_reopened': 'pclDateReopened',  # noqa: E501
        'pcl_date_termed': 'pclDateTermed',  # noqa: E501
        'pcl_disposition': 'pclDisposition',  # noqa: E501
        'pcl_disposition_method': 'pclDispositionMethod',  # noqa: E501
        'pcl_joint_bankruptcy_flag': 'pclJointBankruptcyFlag',  # noqa: E501
        'pcl_joint_discharged_date': 'pclJointDischargedDate',  # noqa: E501
        'pcl_joint_dismissed_date': 'pclJointDismissedDate',  # noqa: E501
        'pcl_joint_disposition_method': 'pclJointDispositionMethod',  # noqa: E501
        'pcl_nature_of_suit': 'pclNatureOfSuit',  # noqa: E501
    }

    read_only_vars = {
    }

    _composed_schemas = {}

    @classmethod
    @convert_js_args_to_python_args
    def _from_openapi_data(cls, pcl_case_link, pcl_jurisdiction_type, pcl_case_id, pcl_case_number_full, pcl_case_title, pcl_case_office, pcl_case_number, pcl_case_type, pcl_case_year, pcl_court_id, pcl_date_filed, pcl_jpml_number, pcl_mdl_court_id, pcl_mdl_date_ordered, pcl_mdl_date_received, pcl_mdl_extension, pcl_mdl_judge_last_name, pcl_mdl_littype, pcl_mdl_status, pcl_mdl_transferee, pcl_mdl_transferee_district, pcl_civil_cto_number, pcl_civil_date_disposition, pcl_civil_date_initiated, pcl_civil_date_terminated, pcl_civil_stat_disposition, pcl_civil_stat_initiated, pcl_civil_stat_terminated, pcl_civil_transferee, pcl_bankruptcy_chapter, pcl_date_discharged, pcl_date_dismissed, pcl_date_reopened, pcl_date_termed, pcl_disposition, pcl_disposition_method, pcl_joint_bankruptcy_flag, pcl_joint_discharged_date, pcl_joint_dismissed_date, pcl_joint_disposition_method, pcl_nature_of_suit, *args, **kwargs):  # noqa: E501
        """PACERCaseSearchContent - a model defined in OpenAPI

        Args:
            pcl_case_link (str, none_type): Link to case in the case management/electronic case files (CM/ECF) system at the court.
            pcl_jurisdiction_type (str, none_type): Link to case in the case management/electronic case files (CM/ECF) system at the court.
            pcl_case_id (int): Sequentially generated number that identifies the case.
            pcl_case_number_full (str, none_type): Case Number.
            pcl_case_title (str, none_type): Title of the case.
            pcl_case_office (str, none_type): The divisional office in which the case was filed.
            pcl_case_number (int): The sequence number of the case.
            pcl_case_type (str, none_type): Code that identifies the type of case.
            pcl_case_year (int): The year in which the case falls. Could be two or four digit.
            pcl_court_id (str, none_type): The general geographical region or specific court district. The court ID is the abbreviation of the court location combined with the court type (dc or bk). Please refer the Appendix B
            pcl_date_filed (str, none_type): Filing date of the case.
            pcl_jpml_number (int, none_type): JPML Case Seed number.
            pcl_mdl_court_id (str, none_type): Which court does this mdl belongs too.
            pcl_mdl_date_ordered (str, none_type): This parameter represents the mdl date ordered of the case when it is present
            pcl_mdl_date_received (str, none_type): This parameter represents the mdl date received of the case when it is present
            pcl_mdl_extension (str, none_type): This parameter represents the mdl extension of the case when it is present
            pcl_mdl_judge_last_name (str, none_type): This parameter represents the mdl judge lastname of the case when it is present
            pcl_mdl_littype (str, none_type): This parameter represents the mdl lit type of the case when it is present
            pcl_mdl_status (str, none_type): This parameter represents the mdl status of the case when it is present
            pcl_mdl_transferee (str, none_type): This parameter represents the mdl transferee of the case when it is present
            pcl_mdl_transferee_district (str, none_type): This parameter represents the mdl transferee district of the case when it is present
            pcl_civil_cto_number (str, none_type): This parameter represents the civil cto number of the case when it is present
            pcl_civil_date_disposition (str, none_type): This parameter represents the civil disposition date of the case when it is present
            pcl_civil_date_initiated (str, none_type): This parameter represents the civil initiated date of the case when it is present
            pcl_civil_date_terminated (str, none_type): This parameter represents the civil terminated date of the case when it is present
            pcl_civil_stat_disposition (str, none_type): This parameter represents the civil stat disposition of the case when it is present
            pcl_civil_stat_initiated (str, none_type): This parameter represents the civil stat initiated of the case when it is present
            pcl_civil_stat_terminated (str, none_type): This parameter represents the civil stat terminated of the case when it is present
            pcl_civil_transferee (str, none_type): This parameter represents the civil transferee of the case when it is present
            pcl_bankruptcy_chapter (str, none_type): This parameter represents the bankruptcy chapter of the case when it is present
            pcl_date_discharged (str, none_type): This parameter represents the date discharged of the case when it is present
            pcl_date_dismissed (str, none_type): This parameter represents the date dismissed of the case when it is present
            pcl_date_reopened (str, none_type): This parameter represents the date reopened of the case when it is present
            pcl_date_termed (str, none_type): This parameter represents the date termed of the case when it is present
            pcl_disposition (str, none_type): This parameter represents the disposition of the case when it is present
            pcl_disposition_method (str, none_type): This parameter represents the disposition method of the case when it is present
            pcl_joint_bankruptcy_flag (str, none_type): This parameter represents the joint bankruptcy flag of the case when it is present
            pcl_joint_discharged_date (str, none_type): This parameter represents the joint discharged date of the case when it is present
            pcl_joint_dismissed_date (str, none_type): This parameter represents the joint dismissed date of the case when it is present
            pcl_joint_disposition_method (str, none_type): This parameter represents the joint disposition method of the case when it is present
            pcl_nature_of_suit (str, none_type): This parameter represents the nature of suit of the case when it is present

        Keyword Args:
            object (str): Name of the object. defaults to "PACERCaseSearchContent"  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        object = kwargs.get('object', "PACERCaseSearchContent")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', True)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        self = super(OpenApiModel, cls).__new__(cls)

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.object = object
        self.pcl_case_link = pcl_case_link
        self.pcl_jurisdiction_type = pcl_jurisdiction_type
        self.pcl_case_id = pcl_case_id
        self.pcl_case_number_full = pcl_case_number_full
        self.pcl_case_title = pcl_case_title
        self.pcl_case_office = pcl_case_office
        self.pcl_case_number = pcl_case_number
        self.pcl_case_type = pcl_case_type
        self.pcl_case_year = pcl_case_year
        self.pcl_court_id = pcl_court_id
        self.pcl_date_filed = pcl_date_filed
        self.pcl_jpml_number = pcl_jpml_number
        self.pcl_mdl_court_id = pcl_mdl_court_id
        self.pcl_mdl_date_ordered = pcl_mdl_date_ordered
        self.pcl_mdl_date_received = pcl_mdl_date_received
        self.pcl_mdl_extension = pcl_mdl_extension
        self.pcl_mdl_judge_last_name = pcl_mdl_judge_last_name
        self.pcl_mdl_littype = pcl_mdl_littype
        self.pcl_mdl_status = pcl_mdl_status
        self.pcl_mdl_transferee = pcl_mdl_transferee
        self.pcl_mdl_transferee_district = pcl_mdl_transferee_district
        self.pcl_civil_cto_number = pcl_civil_cto_number
        self.pcl_civil_date_disposition = pcl_civil_date_disposition
        self.pcl_civil_date_initiated = pcl_civil_date_initiated
        self.pcl_civil_date_terminated = pcl_civil_date_terminated
        self.pcl_civil_stat_disposition = pcl_civil_stat_disposition
        self.pcl_civil_stat_initiated = pcl_civil_stat_initiated
        self.pcl_civil_stat_terminated = pcl_civil_stat_terminated
        self.pcl_civil_transferee = pcl_civil_transferee
        self.pcl_bankruptcy_chapter = pcl_bankruptcy_chapter
        self.pcl_date_discharged = pcl_date_discharged
        self.pcl_date_dismissed = pcl_date_dismissed
        self.pcl_date_reopened = pcl_date_reopened
        self.pcl_date_termed = pcl_date_termed
        self.pcl_disposition = pcl_disposition
        self.pcl_disposition_method = pcl_disposition_method
        self.pcl_joint_bankruptcy_flag = pcl_joint_bankruptcy_flag
        self.pcl_joint_discharged_date = pcl_joint_discharged_date
        self.pcl_joint_dismissed_date = pcl_joint_dismissed_date
        self.pcl_joint_disposition_method = pcl_joint_disposition_method
        self.pcl_nature_of_suit = pcl_nature_of_suit
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
        return self

    required_properties = set([
        '_data_store',
        '_check_type',
        '_spec_property_naming',
        '_path_to_item',
        '_configuration',
        '_visited_composed_classes',
    ])

    @convert_js_args_to_python_args
    def __init__(self, pcl_case_link, pcl_jurisdiction_type, pcl_case_id, pcl_case_number_full, pcl_case_title, pcl_case_office, pcl_case_number, pcl_case_type, pcl_case_year, pcl_court_id, pcl_date_filed, pcl_jpml_number, pcl_mdl_court_id, pcl_mdl_date_ordered, pcl_mdl_date_received, pcl_mdl_extension, pcl_mdl_judge_last_name, pcl_mdl_littype, pcl_mdl_status, pcl_mdl_transferee, pcl_mdl_transferee_district, pcl_civil_cto_number, pcl_civil_date_disposition, pcl_civil_date_initiated, pcl_civil_date_terminated, pcl_civil_stat_disposition, pcl_civil_stat_initiated, pcl_civil_stat_terminated, pcl_civil_transferee, pcl_bankruptcy_chapter, pcl_date_discharged, pcl_date_dismissed, pcl_date_reopened, pcl_date_termed, pcl_disposition, pcl_disposition_method, pcl_joint_bankruptcy_flag, pcl_joint_discharged_date, pcl_joint_dismissed_date, pcl_joint_disposition_method, pcl_nature_of_suit, *args, **kwargs):  # noqa: E501
        """PACERCaseSearchContent - a model defined in OpenAPI

        Args:
            pcl_case_link (str, none_type): Link to case in the case management/electronic case files (CM/ECF) system at the court.
            pcl_jurisdiction_type (str, none_type): Link to case in the case management/electronic case files (CM/ECF) system at the court.
            pcl_case_id (int): Sequentially generated number that identifies the case.
            pcl_case_number_full (str, none_type): Case Number.
            pcl_case_title (str, none_type): Title of the case.
            pcl_case_office (str, none_type): The divisional office in which the case was filed.
            pcl_case_number (int): The sequence number of the case.
            pcl_case_type (str, none_type): Code that identifies the type of case.
            pcl_case_year (int): The year in which the case falls. Could be two or four digit.
            pcl_court_id (str, none_type): The general geographical region or specific court district. The court ID is the abbreviation of the court location combined with the court type (dc or bk). Please refer the Appendix B
            pcl_date_filed (str, none_type): Filing date of the case.
            pcl_jpml_number (int, none_type): JPML Case Seed number.
            pcl_mdl_court_id (str, none_type): Which court does this mdl belongs too.
            pcl_mdl_date_ordered (str, none_type): This parameter represents the mdl date ordered of the case when it is present
            pcl_mdl_date_received (str, none_type): This parameter represents the mdl date received of the case when it is present
            pcl_mdl_extension (str, none_type): This parameter represents the mdl extension of the case when it is present
            pcl_mdl_judge_last_name (str, none_type): This parameter represents the mdl judge lastname of the case when it is present
            pcl_mdl_littype (str, none_type): This parameter represents the mdl lit type of the case when it is present
            pcl_mdl_status (str, none_type): This parameter represents the mdl status of the case when it is present
            pcl_mdl_transferee (str, none_type): This parameter represents the mdl transferee of the case when it is present
            pcl_mdl_transferee_district (str, none_type): This parameter represents the mdl transferee district of the case when it is present
            pcl_civil_cto_number (str, none_type): This parameter represents the civil cto number of the case when it is present
            pcl_civil_date_disposition (str, none_type): This parameter represents the civil disposition date of the case when it is present
            pcl_civil_date_initiated (str, none_type): This parameter represents the civil initiated date of the case when it is present
            pcl_civil_date_terminated (str, none_type): This parameter represents the civil terminated date of the case when it is present
            pcl_civil_stat_disposition (str, none_type): This parameter represents the civil stat disposition of the case when it is present
            pcl_civil_stat_initiated (str, none_type): This parameter represents the civil stat initiated of the case when it is present
            pcl_civil_stat_terminated (str, none_type): This parameter represents the civil stat terminated of the case when it is present
            pcl_civil_transferee (str, none_type): This parameter represents the civil transferee of the case when it is present
            pcl_bankruptcy_chapter (str, none_type): This parameter represents the bankruptcy chapter of the case when it is present
            pcl_date_discharged (str, none_type): This parameter represents the date discharged of the case when it is present
            pcl_date_dismissed (str, none_type): This parameter represents the date dismissed of the case when it is present
            pcl_date_reopened (str, none_type): This parameter represents the date reopened of the case when it is present
            pcl_date_termed (str, none_type): This parameter represents the date termed of the case when it is present
            pcl_disposition (str, none_type): This parameter represents the disposition of the case when it is present
            pcl_disposition_method (str, none_type): This parameter represents the disposition method of the case when it is present
            pcl_joint_bankruptcy_flag (str, none_type): This parameter represents the joint bankruptcy flag of the case when it is present
            pcl_joint_discharged_date (str, none_type): This parameter represents the joint discharged date of the case when it is present
            pcl_joint_dismissed_date (str, none_type): This parameter represents the joint dismissed date of the case when it is present
            pcl_joint_disposition_method (str, none_type): This parameter represents the joint disposition method of the case when it is present
            pcl_nature_of_suit (str, none_type): This parameter represents the nature of suit of the case when it is present

        Keyword Args:
            object (str): Name of the object. defaults to "PACERCaseSearchContent"  # noqa: E501
            _check_type (bool): if True, values for parameters in openapi_types
                                will be type checked and a TypeError will be
                                raised if the wrong type is input.
                                Defaults to True
            _path_to_item (tuple/list): This is a list of keys or values to
                                drill down to the model in received_data
                                when deserializing a response
            _spec_property_naming (bool): True if the variable names in the input data
                                are serialized names, as specified in the OpenAPI document.
                                False if the variable names in the input data
                                are pythonic names, e.g. snake case (default)
            _configuration (Configuration): the instance to use when
                                deserializing a file_type parameter.
                                If passed, type conversion is attempted
                                If omitted no type conversion is done.
            _visited_composed_classes (tuple): This stores a tuple of
                                classes that we have traveled through so that
                                if we see that class again we will not use its
                                discriminator again.
                                When traveling through a discriminator, the
                                composed schema that is
                                is traveled through is added to this set.
                                For example if Animal has a discriminator
                                petType and we pass in "Dog", and the class Dog
                                allOf includes Animal, we move through Animal
                                once using the discriminator, and pick Dog.
                                Then in Dog, we will make an instance of the
                                Animal class but this time we won't travel
                                through its discriminator because we passed in
                                _visited_composed_classes = (Animal,)
        """

        object = kwargs.get('object', "PACERCaseSearchContent")
        _check_type = kwargs.pop('_check_type', True)
        _spec_property_naming = kwargs.pop('_spec_property_naming', False)
        _path_to_item = kwargs.pop('_path_to_item', ())
        _configuration = kwargs.pop('_configuration', None)
        _visited_composed_classes = kwargs.pop('_visited_composed_classes', ())

        if args:
            for arg in args:
                if isinstance(arg, dict):
                    kwargs.update(arg)
                else:
                    raise ApiTypeError(
                        "Invalid positional arguments=%s passed to %s. Remove those invalid positional arguments." % (
                            args,
                            self.__class__.__name__,
                        ),
                        path_to_item=_path_to_item,
                        valid_classes=(self.__class__,),
                    )

        self._data_store = {}
        self._check_type = _check_type
        self._spec_property_naming = _spec_property_naming
        self._path_to_item = _path_to_item
        self._configuration = _configuration
        self._visited_composed_classes = _visited_composed_classes + (self.__class__,)

        self.object = object
        self.pcl_case_link = pcl_case_link
        self.pcl_jurisdiction_type = pcl_jurisdiction_type
        self.pcl_case_id = pcl_case_id
        self.pcl_case_number_full = pcl_case_number_full
        self.pcl_case_title = pcl_case_title
        self.pcl_case_office = pcl_case_office
        self.pcl_case_number = pcl_case_number
        self.pcl_case_type = pcl_case_type
        self.pcl_case_year = pcl_case_year
        self.pcl_court_id = pcl_court_id
        self.pcl_date_filed = pcl_date_filed
        self.pcl_jpml_number = pcl_jpml_number
        self.pcl_mdl_court_id = pcl_mdl_court_id
        self.pcl_mdl_date_ordered = pcl_mdl_date_ordered
        self.pcl_mdl_date_received = pcl_mdl_date_received
        self.pcl_mdl_extension = pcl_mdl_extension
        self.pcl_mdl_judge_last_name = pcl_mdl_judge_last_name
        self.pcl_mdl_littype = pcl_mdl_littype
        self.pcl_mdl_status = pcl_mdl_status
        self.pcl_mdl_transferee = pcl_mdl_transferee
        self.pcl_mdl_transferee_district = pcl_mdl_transferee_district
        self.pcl_civil_cto_number = pcl_civil_cto_number
        self.pcl_civil_date_disposition = pcl_civil_date_disposition
        self.pcl_civil_date_initiated = pcl_civil_date_initiated
        self.pcl_civil_date_terminated = pcl_civil_date_terminated
        self.pcl_civil_stat_disposition = pcl_civil_stat_disposition
        self.pcl_civil_stat_initiated = pcl_civil_stat_initiated
        self.pcl_civil_stat_terminated = pcl_civil_stat_terminated
        self.pcl_civil_transferee = pcl_civil_transferee
        self.pcl_bankruptcy_chapter = pcl_bankruptcy_chapter
        self.pcl_date_discharged = pcl_date_discharged
        self.pcl_date_dismissed = pcl_date_dismissed
        self.pcl_date_reopened = pcl_date_reopened
        self.pcl_date_termed = pcl_date_termed
        self.pcl_disposition = pcl_disposition
        self.pcl_disposition_method = pcl_disposition_method
        self.pcl_joint_bankruptcy_flag = pcl_joint_bankruptcy_flag
        self.pcl_joint_discharged_date = pcl_joint_discharged_date
        self.pcl_joint_dismissed_date = pcl_joint_dismissed_date
        self.pcl_joint_disposition_method = pcl_joint_disposition_method
        self.pcl_nature_of_suit = pcl_nature_of_suit
        for var_name, var_value in kwargs.items():
            if var_name not in self.attribute_map and \
                        self._configuration is not None and \
                        self._configuration.discard_unknown_keys and \
                        self.additional_properties_type is None:
                # discard variable.
                continue
            setattr(self, var_name, var_value)
            if var_name in self.read_only_vars:
                raise ApiAttributeError(f"`{var_name}` is a read-only attribute. Use `from_openapi_data` to instantiate "
                                     f"class with read only attributes.")



from unicourt.api.usage_api import UsageApi
from unicourt import utils
class Usage:

    @staticmethod
    def get_billing_cycles(
        **kwargs
    ):

        """Get all the previous 12 billing cycles.  


        An endpoint to obtain information on the previous 12 billing cycles.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return UsageApi(api_client).get_billing_cycles(
        **kwargs
    )

    @staticmethod
    def get_billing_usage_by_billing_cycle(
        billing_cycle,
        **kwargs
    ):

        """Specify the billing cycle to know the API usage.  


        An endpoint to obtain information on API usage for a specific billing cycle.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return UsageApi(api_client).get_billing_usage_by_billing_cycle(
        billing_cycle,
        **kwargs
    )

    @staticmethod
    def get_daily_usage_by_date(
        date,
        **kwargs
    ):

        """Get API usage for a requested Date.  


        An endpoint to obtain information on API usage for a specific day.  

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return UsageApi(api_client).get_daily_usage_by_date(
        date,
        **kwargs
    )



from unicourt.sdk.Usage import Usage


class TestUsageAPI:
    def test_get_billing_cycles():
        return Usage.get_billing_cycles()

    def test_get_billing_usage_by_billing_cycle():
        billing_obj, status = Usage.get_billing_cycles()
        billing_cycle_date = billing_obj.billing_cycle_array[0]
        return Usage.get_billing_usage_by_billing_cycle(
            billing_cycle=billing_cycle_date)

    def test_get_daily_usage_by_date():
        return Usage.get_daily_usage_by_date(date='2023-02-21')



"""
    UniCourt Enterprise APIs

    <button><a href=\"/enterpriseapi/download/UniCourt-Enterprise-API-Spec.yaml\" >Download UniCourt Enterprise APIs Specification</a></button>   # noqa: E501

    The version of the OpenAPI document: 
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from unicourt.api_client import ApiClient, Endpoint as _Endpoint
from unicourt.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from unicourt.model.case_update import CaseUpdate
from unicourt.model.case_update_list_response import CaseUpdateListResponse
from unicourt.model.case_update_request import CaseUpdateRequest
from unicourt.model.exception import Exception


class CaseUpdateApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.get_case_update_by_case_id_endpoint = _Endpoint(
            settings={
                'response_type': (CaseUpdate,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseUpdate/{caseId}',
                'operation_id': 'get_case_update_by_case_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_id',
                ],
                'required': [
                    'case_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'case_id',
                ]
            },
            root_map={
                'validations': {
                    ('case_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_id':
                        (str,),
                },
                'attribute_map': {
                    'case_id': 'caseId',
                },
                'location_map': {
                    'case_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.get_case_updates_endpoint = _Endpoint(
            settings={
                'response_type': (CaseUpdateListResponse,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseUpdates',
                'operation_id': 'get_case_updates',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_id',
                    'requested_date',
                    'status',
                    'page_number',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'status',
                ],
                'validation': [
                    'case_id',
                    'requested_date',
                    'status',
                    'page_number',
                ]
            },
            root_map={
                'validations': {
                    ('case_id',): {
                        'max_length': 18,
                        'min_length': 18,
                    },
                    ('requested_date',): {
                        'max_length': 25,
                        'min_length': 25,
                    },
                    ('status',): {
                        'max_length': 11,
                        'min_length': 7,
                    },
                    ('page_number',): {

                        'inclusive_minimum': 1,
                    },
                },
                'allowed_values': {
                    ('status',): {

                        "IN_PROGRESS": "IN_PROGRESS",
                        "COMPLETE": "COMPLETE",
                        "FAILURE": "FAILURE",
                        "DELAYED": "DELAYED"
                    },
                },
                'openapi_types': {
                    'case_id':
                        (str,),
                    'requested_date':
                        (datetime,),
                    'status':
                        (str,),
                    'page_number':
                        (int,),
                },
                'attribute_map': {
                    'case_id': 'caseId',
                    'requested_date': 'requestedDate',
                    'status': 'status',
                    'page_number': 'pageNumber',
                },
                'location_map': {
                    'case_id': 'query',
                    'requested_date': 'query',
                    'status': 'query',
                    'page_number': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.update_case_endpoint = _Endpoint(
            settings={
                'response_type': (CaseUpdate,),
                'auth': [
                    'bearerAuth'
                ],
                'endpoint_path': '/caseUpdate',
                'operation_id': 'update_case',
                'http_method': 'PUT',
                'servers': None,
            },
            params_map={
                'all': [
                    'case_update_request',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'case_update_request':
                        (CaseUpdateRequest,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'case_update_request': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )

    def get_case_update_by_case_id(
        self,
        case_id,
        **kwargs
    ):
        """Get Case Updates for a requested CaseId.  # noqa: E501

        Retrieve case updates for the specified case object.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_update_by_case_id(case_id, async_req=True)
        >>> result = thread.get()

        Args:
            case_id (str): The caseId value of the case object for which updates are to be retrieved.

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseUpdate
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        kwargs['case_id'] = \
            case_id
        return self.get_case_update_by_case_id_endpoint.call_with_http_info(**kwargs)

    def get_case_updates(
        self,
        **kwargs
    ):
        """Get Case Update  list for a requested Date.  # noqa: E501

        Retrieve case updates for the specified date.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_case_updates(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            case_id (str): The caseId value of the case for which updates should be retrieved.. [optional]
            requested_date (datetime): The date for which case updates are to be retrieved.. [optional]
            status (str): Status of the case updates to be retrieved.. [optional]
            page_number (int): The page number of the callbacks to be retrieved.<br>   - Minimum: 1 . [optional] if omitted the server will use the default value of 1
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseUpdateListResponse
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.get_case_updates_endpoint.call_with_http_info(**kwargs)

    def update_case(
        self,
        **kwargs
    ):
        """Add Case Update for the requested Case Id.  # noqa: E501

        Request case updates for the specified case. The status will be ``IN_PROGRESS`` after it has been requested. If the request is not processed within 4 hours, it will be reported as ``DELAYED``.  If the request is still incomplete after 4 hours, it will remain in the DELAYED status for up to 72 hours after the request was approved. Such requests will be recorded as ``TIMEOUT`` after 72 hours.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_case(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            case_update_request (CaseUpdateRequest): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            _request_auths (list): set to override the auth_settings for an a single
                request; this effectively ignores the authentication
                in the spec for a single request.
                Default is None
            async_req (bool): execute request asynchronously

        Returns:
            CaseUpdate
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['_request_auths'] = kwargs.get('_request_auths', None)
        return self.update_case_endpoint.call_with_http_info(**kwargs)




from unicourt.api.case_search_api import CaseSearchApi
from unicourt import utils
class CaseSearch:

    @staticmethod
    def search_cases(
        q,
        **kwargs
    ):

        """Case search.  


        This endpoint retrieves cases according to keyword expressions you provide. <br> Keyword expressions are constructed according to the rules described below. <br><br> This API supports multiple use cases:    - Search for multiple keywords  `Google OR Facebook`.   - Search within particular attributes.   - Relational search using terms and connectors.   - And much more. ----  ## Allowed Connectors in Keyword Expressions | Connector | Description  | Example | | ------| ------|------| | **AND** |Find cases containing each of the terms joined by AND connectors.|**personal AND injury**| | **OR**  |Find cases containing any of the terms joined by OR connectors.|**order OR decision**| | **NOT** |Find cases that do not contain the specified term.|**personal AND NOT injury**.  Find cases with the word “personal” and not “injury”.| | **“[phrase]”** |Find the exact phrase placed between the quotation marks.|**\"personal injury”**| | **~**  |Find cases in which the specified words appear near each other. For example, \"personal injury\" ~ 5 targets cases in which the word \"personal\" appears within 5 words of the word \"injury\".|**“personal injury” ~ 5** - Find cases with “personal” within five words of “injury”. | | **( … )** |Specifies the order in which connectors are to be appliied in a keyword expression.| **personal AND (injury OR fall)** - Find cases with the word personal injury or personal fall.|  <br><br> ## Fields and Connectors Searching | Filed | Description  | Example | | ------| ------|------| |**caseNumber** |Find cases with the specified case number (i.e., docket number).| **caseNumber:\"2020-L-007212\"** - Find cases whose case number matches given case number number.| |**caseName** |Find cases with the specified case title.| **caseName:\"THOMAS P. CARNEY, INC. VS BEHLER JAMES Et Al\"** - Find cases whose case name matches given terms.| |**Court**|Find cases in the specified court.|**(Court:(name:(New York)))** - Find cases in New York state.<br>| |**CaseStatus**|Find cases witih the specified case status.|**(CaseStatus:(name:Disposed))** - All disposed cases.<br>| |**CaseType**|Find cases of the specified case type. | **(CaseType:(name:Property))** - Cases with case type “property”.| |**Party** | Find cases involving the specified party.| **(Party:(name:Apple))** - Find cases involving Apple. | |**partyId**|Find cases involving a party with the specified partyId value.|**(Party:(partyId:\"PRTYgu1ffe866484c2\"))**| |**PartyRole** | Find cases in which at least one party has the specified party role. | **(Party:((PartyRole:(name:\"plaintiff\"))))** - Find cases with party role “plaintiff”.<br><br> **(Party:((PartyRole:(name:defendant)) AND (AttorneyRepresentationType:(name:(Attorney represented)))))** - Find cases where a party is acting as defendant and represented by an attorney.| |**AttorneyRepresentationType**| Find cases in which at least one party has the specified attorney representation type.|**(Party:(AttorneyRepresentationType:(name:\"attorney represented\")))** - Find cases where a party is represented by an attorney. | |**Attorney** | Find cases involving the specified attorney. | **(Attorney:(name:\"David Boies\"))** - Find cases involving the attorney David Boies. | |**AttorneyType**|Find cases involving at least one attorney of the specified attorney type.|**(Attorney:((AttorneyType:(name:\"Lead Attorney\"))))**| |**Judge** |Find cases involving the specified judge. | **(Judge:(name:\"Posner\"))** - Find cases involving Judge Posner.| |**JudgeType**|Find cases involving at least one judge of the specified judge type.|**(Judge:((JudgeType:(name:\"Magistrate\"))))**| |**CaseStats**|Find cases with the specified case statistics.|**(CaseStats:(partyCount:[10 TO 100]))** - Find cases involving 10 to 100 parties.<br>**(CaseStats:(attorneyCount:[2 TO 40]))** - Find cases involving 2 to 40 attorneys.<br>**(CaseStats:(judgeCount:[\\* TO 2]))** - Find cases involving up to 2 judges. <br>**(CaseStats:(docketEntryCount:[10 TO 100]))** - Find cases having 10 to 100 docket_entries. <br>**(CaseStats:(allCaseDocumentCount:[10 TO 100]))** - Find cases having 10 to 100 documents. | |**filedDate** | Find cases that were filed on the specified date or within the specified date range. | **filedDate:[2020-03-15T00:00:00 TO 2021-12-01T00:00:00]** - Find the most recently filed cases between March 15, 2020 and December 1, 2021 (inclusive). | |**lastFetchDate**| Find cases in which UniCourt last checked for updates on the specified date or within the specified date range. |**(lastFetchDate:[now-60d TO \\*\\])** - Find cases that were updated by UniCourt in the last 60 days. | |**lastFetchDateWithUpdates**|Find cases in which UniCourt last detected an update on the specified date or within the specified date range.|**(lastFetchDateWithUpdates:[now-6d TO \\*\\])** - Find cases for the changes found on court site in last 6 days.| |**participantsLastFetchDate**|Find cases in which information cocnerning participants was last updated on the specified date or within the specified date range.|**(participantsLastFetchDate:[now-6d TO \\*\\])** - Find cases where the participant's information was updated in last 6 days.| |**DocketEntry**|Find cases in which at least one docket entry contains the specified text.|**(DocketEntry:(text:(Motion to Compel Responses) AND docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00]))** - Find cases with docket text “Motion to Compel Responses” and action date between 2020-01-01 and 2020-05-01.| |**docketEntryDate**|Find cases in which at least one docket entry was made on the specified date or within the specified date range.|**(DocketEntry:(docketEntryDate:[2020-01-01T00:00:00 TO 2020-05-01T00:00:00])) AND (CaseStats:(allCaseDocumentCount:[0 TO 10]))** - Find cases with docket action date between 2020-01-01 and 2020-05-01 having up to 10 documents associated with it.| |**HearingDate**| Find cases with at least one hearing scheduled for the specified date or within the specified date range.|**(Hearing:(hearingDate:[now TO now+10d]))** - Find cases where hearing is scheduled in next 10 days.| |**HearingDate**| Search for cases where hearing is going to happen in 10 to 20days.|**(Hearing:(hearingDate:[now+10d TO now+20d]))** - Find cases where hearing is scheduled in next 10 to 20 days.| |**JurisdictionGeo**|Find cases in which the law of the specified state governs.|**(JurisdictionGeo:(state:\"New York\"))**- Find cases where Jurisdiction is New York state.| |**Party Address Exists**|Find cases with Party addresses.|**(Party:(Contact:(Address:(stateName:\\*))))**- Returns only those cases that have addresses for parties.| |**Document**|Find cases with specific document name and preview is available for the document.|**(CaseDocument:(name:\"civil case cover sheet\" AND isPreviewAvailable:true))**- Returns cases with document civil case cover sheet and preview is available.|  <br><br> --- ## Party Sub Filter Examples |Example |Explanation | |---|---| |**(Party:(name:google AND (PartyRole:(name:\"plaintiff\"))))**|Find cases involving at least one plaintiff whose name contains the term \"Google\".| |**(Party:(name:\"OTELIA PEREIDA\" AND (AttorneyRepresentationType:(name:\"Attorney represented\")))) AND (Attorney:(name:\"Law Offices of Todd M Friedman\"))**|Find cases where the Party is *OTELIA PEREIDA* and is represented by the attorney *Law Offices of Todd M Friedman*.|  --- ### All query parameters supported for this API can be found in below schema section. Schema -->  CaseSearchQueryObject   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseSearchApi(api_client).search_cases(
        q,
        **kwargs
    )

    @staticmethod
    def search_cases_by_id(
        case_search_id,
        **kwargs
    ):

        """Case search results for a given caseSearchId.  


        Retrieve the search results corresponding to the specified caseSearchId value.   

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        """
        with utils.api_client() as api_client:
            return CaseSearchApi(api_client).search_cases_by_id(
        case_search_id,
        **kwargs
    )
